@@ -5,13 +5,12 @@ use warnings;
 use utf8;
 use Any::Moose;
 
-use base "WWW::eNom";
+use parent "WWW::eNom";
 
 warnings::warnif(
-	deprecated => "This module is deprecated; use WWW::eNom instead."
-);
+	deprecated => "This module is deprecated; use WWW::eNom instead." );
 
-our $VERSION = 'v1.0.6'; # VERSION
+our $VERSION = 'v1.1.0'; # VERSION
 # ABSTRACT: DEPRECATED: namespace retired
 
 1;
